package kr.co.vividnext.sodalive.live.roulette.config

import android.os.Bundle
import com.google.android.material.tabs.TabLayout
import kr.co.vividnext.sodalive.R
import kr.co.vividnext.sodalive.base.BaseActivity
import kr.co.vividnext.sodalive.databinding.ActivityRouletteConfigBinding

class RouletteConfigActivity : BaseActivity<ActivityRouletteConfigBinding>(
    ActivityRouletteConfigBinding::inflate
) {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        changeFragment("settings")
    }

    override fun setupView() {
        binding.toolbar.tvBack.text = "룰렛설정"
        binding.toolbar.tvBack.setOnClickListener { finish() }

        val tabs = binding.tabs
        tabs.addTab(tabs.newTab().setText("룰렛설정").setTag("settings"))
        tabs.addTab(tabs.newTab().setText("당첨내역").setTag("winning-details"))
        tabs.addOnTabSelectedListener(object : TabLayout.OnTabSelectedListener {
            override fun onTabSelected(tab: TabLayout.Tab) {
                val tag = tab.tag as String
                changeFragment(tag)
            }

            override fun onTabUnselected(tab: TabLayout.Tab) {
            }

            override fun onTabReselected(tab: TabLayout.Tab) {
            }
        })
    }

    private fun changeFragment(tag: String) {
        val fragmentManager = supportFragmentManager
        val fragmentTransaction = fragmentManager.beginTransaction()

        val currentFragment = fragmentManager.primaryNavigationFragment
        if (currentFragment != null) {
            fragmentTransaction.hide(currentFragment)
        }

        var fragment = fragmentManager.findFragmentByTag(tag)
        if (fragment == null) {
            fragment = if (tag == "settings") {
                RouletteSettingsFragment()
            } else {
                RouletteWinningDetailsFragment()
            }

            fragmentTransaction.add(R.id.container, fragment, tag)
        } else {
            fragmentTransaction.show(fragment)
        }

        fragmentTransaction.setPrimaryNavigationFragment(fragment)
        fragmentTransaction.setReorderingAllowed(true)
        fragmentTransaction.commitNow()
    }
}
